<?php


namespace Controller;


use Traits\TResponse;
use Util\InstanceProvider;
use Zeedhi\Framework\DTO\Request;
use Zeedhi\Framework\DTO\Response;

class Attachment
{
    use TResponse;

    /**
     * @var \Service\Attachment
     */
    private $attachmentService;

    public function __construct(\Service\Attachment $attachmentService) {
        $this->attachmentService = $attachmentService;
    }

    public function downLoadAttachment(Request $request, Response $response)
    {
        try {
            $param = $request->getParameters();
            $commentId = null;
            if(!empty($param['ID'])){
                $commentId = $param['ID'];
            }
            $filename  = null;
            if(!empty($param['FILENAME'])){
                $filename = $param['FILENAME'];
            }
            $this->attachmentService->downLoadAttachment($commentId);
        }catch (\Exception $ex){
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function downLoadAttachmentGEP(Request $request, Response $response)
    {
        $filename = '';
        $filenameOri = '';
        try {
            $param = $request->getParameters();

            if (!empty($param['FILENAME']) && $param['FILENAME'] !== 'ERROR_DECODE') {
                $filename = base64_decode($param['FILENAME']);
            }
            if (!empty($param['FILE_NAME'])) {
                $filename = $param['FILE_NAME'];
            }
            try {
                $this->attachmentService->downLoadAttachmentGEP($filename);
            } catch (\Exception $ex) {
                if (!empty($param['FILE_NAME_ORI'])) {
                    $filenameOri = $param['FILE_NAME_ORI'];
                    $this->attachmentService->downLoadAttachmentGEP($filenameOri);
                } else {
                    throw $ex;
                }
            }
        } catch (\Exception $e) {
            var_dump($filename);
            var_dump($filenameOri);
            throw $e;
        }
    }

    public function newCallAttachment(Request $request, Response $response) {
        try {
            $row = $request->getParameters();
            $callType           = isset($row["CALL_TYPE"]) ? $row["CALL_TYPE"] : null;
            if($callType == \Service\Call::TYPE_ISSUE && !empty($row['DOCUMENT'])){
                InstanceProvider::getFileUploaderServe()->uploadFilesInRow($row, 'DOCUMENT', 'PmDevOps/Projects');
            }
            $subject            = isset($row["SUBJECT"]) ? $row["SUBJECT"] : '';
            $description        = empty($row['DESCRIPTION']) ? null : $row['DESCRIPTION'];
            $supportCallId      = empty($row['CALL_ID']) ? null : $row['CALL_ID'];
            $createdBy          = empty($row['CREATED_BY']) ? null : $row['CREATED_BY'];
            $document           = empty($row['DOCUMENT']) ? array() : $row['DOCUMENT'];
            $callRelationship   = empty($row['CALL_RELATIONSHIP']) ? null : $row['CALL_RELATIONSHIP'];
            $isPublic   = empty($row['PUBLIC']) ? 'Y' : $row['PUBLIC'];
            $this->attachmentService->newCallAttachment($supportCallId, $description, $document, $createdBy, $callRelationship, $subject, $callType,$isPublic);
        } catch (\Exception $e) {
            $this->sendResponse(['error' => $e->getMessage(), 'code' => $e->getCode()], 500);
        }
    }

    public function deleteProductCallAttachments(Request $request, Response $response) {
        try {
            $rows = $request->getParameters();
            foreach ($rows as $row) {
                $id = $row['ID'];
                $dir = isset($row['FILENAME'])?$row['FILENAME']:null;
                $callRelationship   = empty($row['CALL_RELATIONSHIP']) ? null : $row['CALL_RELATIONSHIP'];
                $callType           = isset($row["CALL_TYPE"]) ? $row["CALL_TYPE"] : null;
                $isIssue = $callType == \Service\Call::TYPE_ISSUE;
                $this->attachmentService->deleteProductCallAttachments($id,$isIssue,$dir);
            }

        } catch (\Exception $e) {
            $response->addMessage(new Response\Message($e->getMessage(), Response\Message::TYPE_WARNING));
        }

    }

    public function findAllSpecification(Request $request, Response $response) {
        try {
            $row = $request->getParameters();
            $callType           = empty($row["CALL_TYPE"]) ? null : $row["CALL_TYPE"];
            $callRelationship   = empty($row['CALL_RELATIONSHIP']) ? null : $row['CALL_RELATIONSHIP'];
            $data =  $this->attachmentService->findAllSpecification($callType, $callRelationship);
            $this->sendResponse($data, 200);
        } catch(\Exception $ex){
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }
}
